==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_ms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Soalan</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Tamatkan permainan semasa?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Dijeda&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klik untuk sambung semula permainan.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Permainan Tamat!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klik untuk mulakan permainan baru.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pilih bahasa aplikasi:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Bahasa Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Sila mulakan semula aplikasi ini supaya perubahan bahasa berkesan.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Skor Gottet</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Aras</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Baris</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klik untuk mulakan permainan baru.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Permainan</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Baru</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Jeda</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Sambung Semula</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>Sk&amp;or</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Tetapan</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Bahasa Aplikasi...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ba&amp;ntuan</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Perih&amp;al</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Perihal &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Kepingan Berikutnya</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Aras</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Baris Dibuang</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Perihal</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Merupakan klon tetris yang saya hasilkan untuk isteri saya</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Hakcipta &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Dikeluarkan dibawah lesen &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_ms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Soalan</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Tamatkan permainan semasa?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Dijeda&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klik untuk sambung semula permainan.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Permainan Tamat!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Klik untuk mulakan permainan baru.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pilih bahasa aplikasi:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Bahasa Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Sila mulakan semula aplikasi ini supaya perubahan bahasa berkesan.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Aras</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Baris</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klik untuk mulakan permainan baru.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Permainan</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Baru</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Jeda</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>Sk&amp;or</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Tetapan</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Bahasa Aplikasi...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ba&amp;ntuan</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Perih&amp;al</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Perihal &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Kepingan Berikutnya</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Aras</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Baris Dibuang</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Perihal</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Hakcipta &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Dikeluarkan dibawah lesen &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
